pub fn map_str(kind: &MathFontKind, s: &str) -> StringExpand description
Convert a string by mapping each character through the font transform.
pub fn map_str(kind: &MathFontKind, s: &str) -> StringConvert a string by mapping each character through the font transform.